summaryrefslogtreecommitdiffstats
path: root/src/kile/kiledocumentinfo.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/kile/kiledocumentinfo.h')
-rw-r--r--src/kile/kiledocumentinfo.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/kile/kiledocumentinfo.h b/src/kile/kiledocumentinfo.h
index 9cc563f..2da4e5b 100644
--- a/src/kile/kiledocumentinfo.h
+++ b/src/kile/kiledocumentinfo.h
@@ -52,7 +52,7 @@ namespace KileStruct
ToDo = 0x100000, FixMe = 0x200000, NewEnvironment = 0x400000
};
//Different levels (in the tqparent-child hierarchy) in the structure view
enum
{
Hidden = -4, NotSpecified = -3, Object = -2, File = -1
@@ -264,7 +264,7 @@ public:
* @warning Only this method should be used to create new views for text documents !
* @return NULL if no document is set (m_doc == NULL)
**/
- KTextEditor::View* createView(TQWidget *tqparent, const char *name=0);
+ KTextEditor::View* createView(TQWidget *parent, const char *name=0);
protected slots:
void slotFileNameChanged();
@@ -52,7 +52,7 @@ namespace KileStruct
ToDo = 0x100000, FixMe = 0x200000, NewEnvironment = 0x400000
};
- //Different levels (in the tqparent-child hierarchy) in the structure view
+ //Different levels (in the parent-child hierarchy) in the structure view
enum
{